@@ -29,7 +29,6 @@ import PlacementRuleModel from './models/placementrule';
 import ClusterModel, { CLUSTER_NAMESPACE_LABEL } from './models/cluster';
 import GenericModel from './models/generic';
 import ComplianceModel from './models/compliance';
-import ResourceViewModel from './models/resourceview';
 import SFModel from './models/findings';
 import ConnectionModel from './models/connection';
 
@@ -81,14 +80,13 @@ const apolloServer = new ApolloServer({
 
     return {
       req,
-      applicationModel: new ApplicationModel({ kubeConnector }),
+      applicationModel: new ApplicationModel({ kubeConnector, updateUserNamespaces }),
       channelModel: new ChannelModel({ kubeConnector }),
       subscriptionModel: new SubscriptionModel({ kubeConnector }),
       placementRuleModel: new PlacementRuleModel({ kubeConnector }),
       clusterModel: new ClusterModel({ kubeConnector, clusterNamespaces, updateUserNamespaces }),
       genericModel: new GenericModel({ kubeConnector }),
       complianceModel: new ComplianceModel({ kubeConnector }),
-      resourceViewModel: new ResourceViewModel({ kubeConnector }),
       sfModel: new SFModel({ kubeConnector, req }),
       connectionModel: new ConnectionModel({ kubeConnector }),
       bareMetalAssetModel: new BareMetalAssetModel({ kubeConnector }),
